Before you install

This is an OS X 10.6/10.7 version of Couchapp.

After you install

This package installs the couchapp executable in /usr/bin and the Couchapp files in /usr/share/couchapp.

Documentation

Visit the Couchapp web site and wiki

You can also visit the, CouchDB website

Reporting problems

If you run into any problems, please file a bug online:

http://github.com/couchapp/couchapp/issues